#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon May 27 15:53:45 2019

@author: hogbobson
"""

from setuptools import setup, find_packages

setup(name='hpsim',
      version='0.0.6',
      description='A modular, high performance particle simulator',
      url='http://github.com/Hogbobson/hpsim',
      author='Mads Kildholt',
      author_email='hogbobson@gmail.com',
      license='GNU General Public License v3',
      packages=find_packages(),
)
